<?php

/**
 * Plugin Name: Payerurl Crypto Currency Payment Gateway for WooCommerce
 * Plugin URI: https://payerurl.com/payerurl-woocommerce-plugin-for-merchant-integration/
 * Author: PayerURL
 * Author URI: https://payerurl.com
 * Description: Makes Crypto Transactions easier for Businesses and Personal payment. Pay securely using Payerurl
 * Version:1.0.2
 * License: GPLv3
 * License URI: https://payerurl.com
 * Text Domain: payerurl-crypto-currency-payment-gateway-for-wooCommerce
 * Domain Path: https://payerurl.com
 */


if (!defined('WPINC')) die("Direct Access Not Allowed");
if (!class_exists('Payerurl')) {
    final class Payerurl
    {
        const version = "1.0.2";
        protected static $_instance = NULL;

        private function __construct()
        {
        }

        public static function getInstance()
        {
            if (is_null(self::$_instance))
                self::$_instance = new self;
            return self::$_instance;
        }

        private function define_constant()
        {
            if (!defined('PAYERURL_PAYMENT_URL'))
                define('PAYERURL_PAYMENT_URL', 'https://dashboard.payerurl.com/api/payment');
            if (!defined('PAYERURL_VERSION')) define('PAYERURL_VERSION', self::version);
            if (!defined('PAYERURL_FILE')) define('PAYERURL_FILE', __FILE__);
            if (!defined('PAYERURL_DIR')) define('PAYERURL_DIR', __DIR__);
            if (!defined('PAYERURL_URL')) define('PAYERURL_URL', plugin_dir_url(PAYERURL_FILE));
        }

        public function init()
        {
            $this->define_constant();
            add_filter(
                'plugin_action_links_' . plugin_basename(PAYERURL_FILE),
                array($this, 'plugin_action_links')
            );
            add_action('plugins_loaded', array($this, "plugins_loaded"));
        }

        private function admin_init()
        {
            if (!$this->is_woocommerce_active()) {
                add_action('admin_notices', array($this, 'woocommerce_admin_notices'), 15);
                return;
            }
        }

        public function plugins_loaded()
        {
            if (is_admin()) $this->admin_init();
            $this->payment_gateway_init();
        }

        private function payment_gateway_init()
        {
            if ($this->is_woocommerce_active() && class_exists('WC_Payment_Gateway')) {
                add_filter('woocommerce_payment_gateways', array($this, 'woocommerce_add_payerurl_gateway'));
                include_once 'class-payerurl-gateway.php';
            }
        }

        public function woocommerce_add_payerurl_gateway($methods)
        {
            $methods[] = 'WC_Payerurl';
            return $methods;
        }

        public function plugin_action_links($links)
        {
            $action_links = array(
                'settings' => sprintf(
                    '<a href="%s" aria-label="%s">%s</a>',
                    admin_url('admin.php?page=wc-settings&tab=checkout&section=wc_payerurl_gateway'),
                    __('View settings', 'payerurl-crypto-currency-payment-gateway-for-wooCommerce'),
                    __('Settings', 'payerurl-crypto-currency-payment-gateway-for-wooCommerce')
                ),
            );
            return array_merge($action_links, $links);
        }

        private function is_woocommerce_active()
        {
            $active_plugins = (array)get_option('active_plugins', array());
            $key = 'woocommerce/woocommerce.php';
            return in_array($key, $active_plugins) || array_key_exists($key, $active_plugins);
        }

        public function woocommerce_admin_notices()
        {
            return sprintf(
                '<div class="error"><p>%s</p></div>',
                __('woocommerce plugin is required for plugin "Payerurl"', 'payerurl-crypto-currency-payment-gateway-for-wooCommerce')
            );
        }
    }
}

function payerurl()
{
    $payerurl = Payerurl::getInstance();
    $payerurl->init();
    return $payerurl;
}

$GLOBALS['payerurl'] = payerurl();
